#
# spec file for package clustershell
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2023 Stephane Thiell <sthiell@stanford.edu>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python2_sitelib: %global python2_sitelib %{python_sitelib}}
%{!?__python: %global __python python}
%{!?__python2: %global __python2 %{__python}}

%if 0%{?sle_version} && 0%{?sle_version} < 150400
%define py2 1
%endif

%if 0%{?suse_version} >= 1500
%{!?python2_pkgversion: %global python2_pkgversion 2}
%global python2_pkgprefix python%{python2_pkgversion}
%else
%global python2_pkgprefix python
%endif

%{!?python3_pkgversion: %global python3_pkgversion 3}
%global python3_pkgprefix python%{python3_pkgversion}

%{!?__python3: %global __python3 python3}
%{!?python3_shortver: %global python3_shortver %(%{__python3} -c 'import sys; print(str(sys.version_info.major) + "." + str(sys.version_info.minor))')}

%global srcname ClusterShell

Name:           clustershell
Version:        1.9.2
Release:        1.6
Summary:        Python framework for efficient cluster administration
License:        LGPL-2.1-or-later
Group:          Productivity/Clustering/Computing

URL:            http://cea-hpc.github.io/clustershell/
Source0:        https://files.pythonhosted.org/packages/source/C/%{srcname}/%{srcname}-%{version}.tar.gz
BuildArch:      noarch
%if 0%{?py2}
Requires:       python2-%{name} = %{version}-%{release}
%else
Requires:       python3-%{name} = %{version}-%{release}
%endif
Requires:       vim
BuildRequires:  fdupes
BuildRequires:  vim
Provides:       vim-clustershell = %{version}-%{release}
Obsoletes:      vim-clustershell < 1.7.81-4

%description
ClusterShell is a set of tools and a Python library to execute commands
on cluster nodes in parallel depending on selected engine and worker
mechanisms. Advanced node sets and node groups handling methods are provided
to ease and improve the daily administration of large compute clusters or
server farms. Command line utilities like clush, clubak and nodeset (or
cluset) allow traditional shell scripts to take benefit of the features
offered by the library.

%if 0%{?py2}
%package -n python2-%{name}
Summary:        ClusterShell module for Python 2
Group:          Productivity/Clustering/Computing
BuildRequires:  %{python2_pkgprefix}-devel
BuildRequires:  %{python2_pkgprefix}-setuptools
Requires:       %{python2_pkgprefix}-setuptools
%if 0%{?suse_version}
Requires:       %{python2_pkgprefix}-PyYAML
%else
Requires:       PyYAML
%endif
%{?python_provide:%python_provide python2-%{name}}

%description -n python2-%{name}
ClusterShell Python 2 module and related command line tools.
%endif

%package -n %{python3_pkgprefix}-%{name}
Summary:        ClusterShell module for Python 3
Group:          Productivity/Clustering/Computing
BuildRequires:  %{python3_pkgprefix}-devel
BuildRequires:  %{python3_pkgprefix}-setuptools
Requires:       %{python3_pkgprefix}-PyYAML
Requires:       %{python3_pkgprefix}-setuptools
%{!?py2:Obsoletes:      python2-%{name}}
%{?python_provide:%python_provide %{python3_pkgprefix}-%{srcname}}

%description -n %{python3_pkgprefix}-%{name}
ClusterShell Python 3 module and related command line tools.

%prep
%setup -q -n %{srcname}-%{version}

%build
%{__python3} setup.py build
%{?py2:%{__python2} setup.py build}

%install
%{__python3} setup.py install -O1 --skip-build --root %{buildroot}

%if 0%{?py2}
pushd %{buildroot}%{_bindir}
for i in clubak cluset clush nodeset; do
  mv $i $i-%{python3_shortver}
done
popd

%{__python2} setup.py install -O1 --skip-build --root %{buildroot}
%endif

# move config dir away from default setuptools /usr prefix (if rpm-building as user)
[ -d %{buildroot}/usr/etc ] && mv %{buildroot}/usr/etc %{buildroot}/%{_sysconfdir}

# man pages
install -d %{buildroot}/%{_mandir}/{man1,man5}
install -p -m 0644 doc/man/man1/clubak.1 %{buildroot}/%{_mandir}/man1/
install -p -m 0644 doc/man/man1/cluset.1 %{buildroot}/%{_mandir}/man1/
install -p -m 0644 doc/man/man1/clush.1 %{buildroot}/%{_mandir}/man1/
install -p -m 0644 doc/man/man1/nodeset.1 %{buildroot}/%{_mandir}/man1/
install -p -m 0644 doc/man/man5/clush.conf.5 %{buildroot}/%{_mandir}/man5/
install -p -m 0644 doc/man/man5/groups.conf.5 %{buildroot}/%{_mandir}/man5/

# vim addons
%define vimdatadir %{_datadir}/vim/site

install -d %{buildroot}/%{vimdatadir}/{ftdetect,syntax}
install -p -m 0644 doc/extras/vim/ftdetect/clustershell.vim %{buildroot}/%{vimdatadir}/ftdetect/
install -p -m 0644 doc/extras/vim/syntax/clushconf.vim %{buildroot}/%{vimdatadir}/syntax/
install -p -m 0644 doc/extras/vim/syntax/groupsconf.vim %{buildroot}/%{vimdatadir}/syntax/
%fdupes %{buildroot}

%if 0%{?py2}
%files -n python2-%{name}
%{_bindir}/clubak
%{_bindir}/cluset
%{_bindir}/clush
%{_bindir}/nodeset
%{python2_sitelib}/ClusterShell/
%{python2_sitelib}/ClusterShell-*-py?.?.egg-info

%files -n %{python3_pkgprefix}-%{name}
%{_bindir}/clubak-%{python3_shortver}
%{_bindir}/cluset-%{python3_shortver}
%{_bindir}/clush-%{python3_shortver}
%{_bindir}/nodeset-%{python3_shortver}
%{python3_sitelib}/ClusterShell/
%{python3_sitelib}/ClusterShell-*-py?.*.egg-info

%else

%files -n %{python3_pkgprefix}-%{name}
%{_bindir}/clubak
%{_bindir}/cluset
%{_bindir}/clush
%{_bindir}/nodeset
%{python3_sitelib}/ClusterShell/
%{python3_sitelib}/ClusterShell-*-py?.*.egg-info
%endif

%files
%doc ChangeLog README.md
%if 0%{?suse_version} >= 1500
%license COPYING.LGPLv2.1
%else
%doc COPYING.LGPLv2.1
%endif
%doc doc/examples
%doc doc/sphinx
%{_mandir}/man1/clubak.1*
%{_mandir}/man1/cluset.1*
%{_mandir}/man1/clush.1*
%{_mandir}/man1/nodeset.1*
%{_mandir}/man5/clush.conf.5*
%{_mandir}/man5/groups.conf.5*
%dir %{_sysconfdir}/clustershell
%dir %{_sysconfdir}/clustershell/clush.conf.d
%dir %{_sysconfdir}/clustershell/groups.d
%dir %{_sysconfdir}/clustershell/groups.conf.d
%config(noreplace) %{_sysconfdir}/clustershell/clush.conf
%config(noreplace) %{_sysconfdir}/clustershell/groups.conf
%ghost %{_sysconfdir}/clustershell/groups
%config(noreplace) %{_sysconfdir}/clustershell/groups.d/local.cfg
%doc %{_sysconfdir}/clustershell/clush.conf.d/README
%doc %{_sysconfdir}/clustershell/clush.conf.d/*.conf.example
%doc %{_sysconfdir}/clustershell/groups.conf.d/README
%doc %{_sysconfdir}/clustershell/groups.conf.d/*.conf.example
%doc %{_sysconfdir}/clustershell/groups.d/README
%doc %{_sysconfdir}/clustershell/groups.d/*.yaml.example
%doc %{_sysconfdir}/clustershell/topology.conf.example
%{vimdatadir}/ftdetect/clustershell.vim
%{vimdatadir}/syntax/clushconf.vim
%{vimdatadir}/syntax/groupsconf.vim

%changelog
* Mon Oct  2 2023 Stephane Thiell <sthiell@stanford.edu>
- Update to upstream release 1.9.2:
  * clush/clubak: fix line buffering with Python 3
  * clush: fix --[r]copy dest when --dest is omitted
  * NodeUtils: allow null values in cluster.yaml
  * Topology: check that node groups/wildcards are non-empty
  * packaging: fix missing xcat.conf.example
* Sat Feb 11 2023 Stephane Thiell <sthiell@stanford.edu>
- Update to upstream release 1.9.1:
  * clush: select proper last parsed config file
  * setup.py: update download url and remove python 2.6 support
  * setup.py: improvements for pip install and venv
  * doc: correct typo 'sterr'
  * Fix typos found with codespell
  * RangeSet: support negative ranges
  * RangeSet: remove duplicate intiter() definition
* Mon Nov 28 2022 Stephane Thiell <sthiell@stanford.edu>
- Update to upstream release 1.9:
  * clush: add --mode support with sudo and sshpass examples
  * clush: add options '--outdir=OUTDIR' and '--errdir=ERRDIR'
  * clush: always close stdin stream of worker when it is not used
  * clush: use daemon attribute instead of deprecated setDaemon()
  * slurm.conf.example: filter out more Slurm node state flags
  * NodeSet: add special notation @@source to expand group names
  * RangeSet: nD folding optimization
  * RangeSet: support ranges with zero padding of mixed lengths
  * RangeSet: add explicit intiter() method to iterate over integers
  * EngineClient: EnginePort improvements, add event ev_port_start()
  * Tree: fix start and bufferize early writes
  * Tree: fix error with intermediate gateways
  * Defaults: Introduce CLUSTERSHELL_CFGDIR
  * Fix for python-3.10
  * Worker: deprecate old EventHandler method signatures
  * Worker: remove old last_*() methods
* Wed May 18 2022 Steve Kowalik <steven.kowalik@suse.com>
- Prepare for Python 3.10 by correcting sitelib install paths.
* Mon Nov  8 2021 Stephane Thiell <sthiell@stanford.edu>
- Update to upstream release 1.8.4:
  * RangeSetND: fix padding info when slicing using __getitem__()
  * Defaults: Allow out-of-tree worker modules
  * NodeUtils: allow YAML list to declare node groups
  * Tree: Use default local_worker and allow overriding Defaults
  * Worker/Rsh: return maxrc properly for Rsh Worker
  * xCAT binding: add support for spaces in group names
  * CLI/Clush: Avoid python3 error with no stdin
  * CLI/Clush: use os.read() in stdin thread
  * CLI/Clush: Add maxrc option to clush.conf
  * CLI/Display: Add support for NO_COLOR and CLICOLOR
* Tue Sep  8 2020 Egbert Eich <eich@suse.com>
- Grab updated spec file from upstream to fix Python2 handling.
* Wed Jul 29 2020 Egbert Eich <eich@suse.com>
- Update to upstream release 1.8.3:
  * Worker/ScpClient: always put remote into brackets (#424)
  * RangeSetND: fix padding info when slicing using __getitem__() (#429)
  * Defaults: Allow out-of-tree worker modules
- Resync spec file with upstream, disable Python2 where not supported
  any more.
- Obsolete python2 package that may be installed when building for
  python3 only.
* Sat Nov 30 2019 Stephane Thiell <sthiell@stanford.edu>
- The correct license is LGPL-2.1-or-later
* Fri Nov 29 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Update to upstream release 1.8.2:
  * clush: support UTF-8 string encoding with --diff
  * in some cases, timers were too fast due to an issue in EngineTimer
  * fix issue in the Slurm group bindings where job ids were used
    instead of user names
  * performance update for xCAT group bindings
- Update Source to download from GitHub directly
- Use %%license and %%fdupes
* Mon Nov 26 2018 Stephane Thiell <sthiell@stanford.edu>
- Update to upstream release 1.8.1:
  * support offline gateways in Tree mode
  * CLI: added --conf and --groupsconf command line options
  * NodeSet: speed-up nodeset parsing
  * EventHandler: reinstate ev_error and ev_timeout as deprecated
  * nodeset/cluset CLI: allow litteral new line in -S
  * nodeset/cluset CLI: handle multiline shell arguments in options
* Thu Oct 26 2017 sthiell@stanford.edu
- Update to new upstream release 1.8:
  * added Python 3 support (3.4+)
  * support for Python 2.5 and below has been dropped
  * new EventHandler API (backward compatible)
  * task.shell() has a new stdin (boolean) argument
  * NodeSet/nodeset/cluset can now handle numeric node names
  * clush now use slightly different colors that are legible on
    dark backgrounds
* Wed Sep 13 2017 sthiell@stanford.edu
- initial support for openSUSE
* Wed Sep  6 2017 sthiell@stanford.edu
- fix condition for ghost groups symlink
* Sun Sep  3 2017 sthiell@stanford.edu
- move vim extensions into the clustershell package
- use Requires: vim-filesystem instead of vim-common
- define upgrade path for vim-clustershell
* Sat Sep  2 2017 sthiell@stanford.edu
- create separate packages for python2 and python3 modules
* Fri Sep  1 2017 sthiell@stanford.edu
- update to 1.7.81 (1.8 beta1)
* Tue Dec 20 2016 sthiell@stanford.edu
- update to 1.7.3
* Sat Jun 18 2016 sthiell@stanford.edu
- update to 1.7.2
* Mon Feb 29 2016 sthiell@stanford.edu
- update to 1.7.1
* Tue Nov 10 2015 sthiell@stanford.edu
- update to 1.7
* Fri Aug  7 2015 stephane.thiell@cea.fr
- update to 1.6.96
* Sun Apr  8 2012 stephane.thiell@cea.fr
- update to 1.6
* Thu Jun  9 2011 stephane.thiell@cea.fr
- update to 1.5.1
* Wed Jun  8 2011 stephane.thiell@cea.fr
- update to 1.5
* Sat Mar 19 2011 stephane.thiell@cea.fr
- update to 1.4.3
* Tue Mar 15 2011 stephane.thiell@cea.fr
- update to 1.4.2
* Sun Feb 13 2011 stephane.thiell@cea.fr
- update to 1.4.1
* Sat Jan 15 2011 stephane.thiell@cea.fr
- update to 1.4
* Wed Oct 20 2010 stephane.thiell@cea.fr
- update to 1.3.3
* Fri Sep 10 2010 stephane.thiell@cea.fr
- renamed Vim subpackage to vim-clustershell
- update to 1.3.2
* Sun Sep  5 2010 stephane.thiell@cea.fr
- added -vim subpackage for .vim files
* Fri Sep  3 2010 stephane.thiell@cea.fr
- removed -n from setup line
- own clustershell config directory for proper uninstall
- install vim syntax addons in vimfiles, thus avoiding vim version detection
- update to 1.3.1
* Sun Aug 22 2010 stephane.thiell@cea.fr
- fixed BuildRoot tag in accordance with EPEL guidelines
- python_sitelib definition: prefer global vs define
- preserve timestamps and fix permissions when installing files
* Sat Aug 21 2010 stephane.thiell@cea.fr
- use a full URL to the package in Source0
* Fri Aug 20 2010 stephane.thiell@cea.fr
- various improvements per first review request
* Thu Aug 19 2010 stephane.thiell@cea.fr
- initial build candidate for Fedora
